/*
 * Author: Magnus Bergman <magnus@snisurset.net>
 *
 * This file is public domain.
 */
#ifndef ABYDOS_VERSION_H
#define ABYDOS_VERSION_H

/**
 * ABYDOS_ENCODE_VERSION
 *
 * This macro encodes the given version into an integer. The numbers
 * returned by %ABYDOS_VERSION and abydos_version() are encoded using this
 * macro. Two encoded version numbers can be compared as integers. The
 * encoding ensures that later versions compare greater than earlier
 * versions.
 */
#define ABYDOS_ENCODE_VERSION(major,minor,micro) \
        ((major) << 16 + (minor) << 8 + (micro))

/**
 * ABYDOS_VERSION
 *
 * The compile-time version of abydos, encoded using ABYDOS_ENCODE_VERSION().
 */
#define ABYDOS_VERSION ABYDOS_ENCODE_VERSION(0,1,3)

/**
 * ABYDOS_VERSION_MAJOR
 *
 * The compile-time major version of abydos (currently 0).
 */
#define ABYDOS_VERSION_MAJOR 0

/**
 * ABYDOS_VERSION_MINOR
 *
 * The compile-time minor version of abydos (currently 1).
 */
#define ABYDOS_VERSION_MINOR 1

/**
 * ABYDOS_VERSION_MICRO
 *
 * The compile-time micro version of abydos (currently 3).
 */
#define ABYDOS_VERSION_MICRO 3

/**
 * ABYDOS_VERSION_STRING
 *
 * The compile-time version of abydos as a string (currently
 * "0.1.3").
 */
#define ABYDOS_VERSION_STRING "0.1.3"

/**
 * ABYDOS_CHECK_VERSION
 * @major: the major version to check for
 * @minor: the minor version to check for
 * @micro: the micro version to check for
 *
 * Checks the compile-time version of abydos.
 * Use abydos_check_version() for a run-time version check.
 *
 * returns: non zero if the compile-time version of abydos is the same as
 *          or newer than the passed-in version.
 **/
#define ABYDOS_CHECK_VERSION(major,minor,micro) (ABYDOS_ENCODE_VERSION(major,minor,micro) >= ABYDOS_VERSION)

int abydos_version(void);
int abydos_major_version(void);
int abydos_minor_version(void);
int abydos_micro_version(void);
const char *abydos_version_string(void);
int abydos_check_version(int major,int minor,int micro);

#endif /* ABYDOS_VERSION_H */
